================
Aldryn MailChimp
================

To activate MailChimp integration:

#. provide an `API Key` while installing an app
#. create an CMS page for hooking the app (navigate to ``Advanced Settings -> Application`` on CMS edit page)

When all above is done, you can add MailChimp integration plugins to placeholders.
